# yamlconf

A simple python library use to load/dump config from yaml file.

`Generated by cookiecutter-rrpylibrary.`


Free software: MIT license

## Documentation


## Features

## TODO

1. add documents

## Credits

This package created by Cookiecutter with the `HuangKaiHuan/cookiecutter-rrpylibrary` project template.

Cookiecutter: https://github.com/audreyr/cookiecutter

`HuangKaiHuan/cookiecutter-rrpylibrary`: https://github.com/HuangKaiHuan/cookiecutter-rrpylibrary
